# infoml

Python package for bioinformatics analysis and machine learning.

## Installation

```bash
$ pip install infoml
```

## Usage

- TODO

## Contributing

Interested in contributing? Check out the contributing guidelines. Please note that
this project is released with a Code of Conduct. By contributing to this project, you
agree to abide by its terms.

## License

`infoml` was created by Tony Kabilan Okeke. It is licensed under the terms of the MIT 
license.

## Credits

`infoml` was created with [`cookiecutter`](https://cookiecutter.readthedocs.io/en/latest/) 
and the `py-pkgs-cookiecutter` [template](https://github.com/py-pkgs/py-pkgs-cookiecutter).

